import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { CodePipelineServiceException as __BaseException } from "./CodePipelineServiceException";
export interface AcknowledgeJobInput {
  jobId: string | undefined;
  nonce: string | undefined;
}
export declare const JobStatus: {
  readonly Created: "Created";
  readonly Dispatched: "Dispatched";
  readonly Failed: "Failed";
  readonly InProgress: "InProgress";
  readonly Queued: "Queued";
  readonly Succeeded: "Succeeded";
  readonly TimedOut: "TimedOut";
};
export type JobStatus = (typeof JobStatus)[keyof typeof JobStatus];
export interface AcknowledgeJobOutput {
  status?: JobStatus | undefined;
}
export declare class InvalidNonceException extends __BaseException {
  readonly name: "InvalidNonceException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidNonceException, __BaseException>
  );
}
export declare class JobNotFoundException extends __BaseException {
  readonly name: "JobNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<JobNotFoundException, __BaseException>
  );
}
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface AcknowledgeThirdPartyJobInput {
  jobId: string | undefined;
  nonce: string | undefined;
  clientToken: string | undefined;
}
export interface AcknowledgeThirdPartyJobOutput {
  status?: JobStatus | undefined;
}
export declare class InvalidClientTokenException extends __BaseException {
  readonly name: "InvalidClientTokenException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidClientTokenException, __BaseException>
  );
}
export declare const ActionCategory: {
  readonly Approval: "Approval";
  readonly Build: "Build";
  readonly Compute: "Compute";
  readonly Deploy: "Deploy";
  readonly Invoke: "Invoke";
  readonly Source: "Source";
  readonly Test: "Test";
};
export type ActionCategory =
  (typeof ActionCategory)[keyof typeof ActionCategory];
export interface ActionConfiguration {
  configuration?: Record<string, string> | undefined;
}
export declare const ActionConfigurationPropertyType: {
  readonly Boolean: "Boolean";
  readonly Number: "Number";
  readonly String: "String";
};
export type ActionConfigurationPropertyType =
  (typeof ActionConfigurationPropertyType)[keyof typeof ActionConfigurationPropertyType];
export interface ActionConfigurationProperty {
  name: string | undefined;
  required: boolean | undefined;
  key: boolean | undefined;
  secret: boolean | undefined;
  queryable?: boolean | undefined;
  description?: string | undefined;
  type?: ActionConfigurationPropertyType | undefined;
}
export interface ActionContext {
  name?: string | undefined;
  actionExecutionId?: string | undefined;
}
export declare const ActionOwner: {
  readonly AWS: "AWS";
  readonly Custom: "Custom";
  readonly ThirdParty: "ThirdParty";
};
export type ActionOwner = (typeof ActionOwner)[keyof typeof ActionOwner];
export interface ActionTypeId {
  category: ActionCategory | undefined;
  owner: ActionOwner | undefined;
  provider: string | undefined;
  version: string | undefined;
}
export interface EnvironmentVariable {
  name: string | undefined;
  value: string | undefined;
}
export interface InputArtifact {
  name: string | undefined;
}
export interface OutputArtifact {
  name: string | undefined;
  files?: string[] | undefined;
}
export interface ActionDeclaration {
  name: string | undefined;
  actionTypeId: ActionTypeId | undefined;
  runOrder?: number | undefined;
  configuration?: Record<string, string> | undefined;
  commands?: string[] | undefined;
  outputArtifacts?: OutputArtifact[] | undefined;
  inputArtifacts?: InputArtifact[] | undefined;
  outputVariables?: string[] | undefined;
  roleArn?: string | undefined;
  region?: string | undefined;
  namespace?: string | undefined;
  timeoutInMinutes?: number | undefined;
  environmentVariables?: EnvironmentVariable[] | undefined;
}
export interface ErrorDetails {
  code?: string | undefined;
  message?: string | undefined;
}
export declare const ActionExecutionStatus: {
  readonly Abandoned: "Abandoned";
  readonly Failed: "Failed";
  readonly InProgress: "InProgress";
  readonly Succeeded: "Succeeded";
};
export type ActionExecutionStatus =
  (typeof ActionExecutionStatus)[keyof typeof ActionExecutionStatus];
export interface ActionExecution {
  actionExecutionId?: string | undefined;
  status?: ActionExecutionStatus | undefined;
  summary?: string | undefined;
  lastStatusChange?: Date | undefined;
  token?: string | undefined;
  lastUpdatedBy?: string | undefined;
  externalExecutionId?: string | undefined;
  externalExecutionUrl?: string | undefined;
  percentComplete?: number | undefined;
  errorDetails?: ErrorDetails | undefined;
  logStreamARN?: string | undefined;
}
export interface S3Location {
  bucket?: string | undefined;
  key?: string | undefined;
}
export interface ArtifactDetail {
  name?: string | undefined;
  s3location?: S3Location | undefined;
}
export interface ActionExecutionInput {
  actionTypeId?: ActionTypeId | undefined;
  configuration?: Record<string, string> | undefined;
  resolvedConfiguration?: Record<string, string> | undefined;
  roleArn?: string | undefined;
  region?: string | undefined;
  inputArtifacts?: ArtifactDetail[] | undefined;
  namespace?: string | undefined;
}
export interface ActionExecutionResult {
  externalExecutionId?: string | undefined;
  externalExecutionSummary?: string | undefined;
  externalExecutionUrl?: string | undefined;
  errorDetails?: ErrorDetails | undefined;
  logStreamARN?: string | undefined;
}
export interface ActionExecutionOutput {
  outputArtifacts?: ArtifactDetail[] | undefined;
  executionResult?: ActionExecutionResult | undefined;
  outputVariables?: Record<string, string> | undefined;
}
export interface ActionExecutionDetail {
  pipelineExecutionId?: string | undefined;
  actionExecutionId?: string | undefined;
  pipelineVersion?: number | undefined;
  stageName?: string | undefined;
  actionName?: string | undefined;
  startTime?: Date | undefined;
  lastUpdateTime?: Date | undefined;
  updatedBy?: string | undefined;
  status?: ActionExecutionStatus | undefined;
  input?: ActionExecutionInput | undefined;
  output?: ActionExecutionOutput | undefined;
}
export declare const StartTimeRange: {
  readonly All: "All";
  readonly Latest: "Latest";
};
export type StartTimeRange =
  (typeof StartTimeRange)[keyof typeof StartTimeRange];
export interface LatestInPipelineExecutionFilter {
  pipelineExecutionId: string | undefined;
  startTimeRange: StartTimeRange | undefined;
}
export interface ActionExecutionFilter {
  pipelineExecutionId?: string | undefined;
  latestInPipelineExecution?: LatestInPipelineExecutionFilter | undefined;
}
export declare class ActionNotFoundException extends __BaseException {
  readonly name: "ActionNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ActionNotFoundException, __BaseException>
  );
}
export interface ActionRevision {
  revisionId: string | undefined;
  revisionChangeId: string | undefined;
  created: Date | undefined;
}
export interface ActionState {
  actionName?: string | undefined;
  currentRevision?: ActionRevision | undefined;
  latestExecution?: ActionExecution | undefined;
  entityUrl?: string | undefined;
  revisionUrl?: string | undefined;
}
export interface ArtifactDetails {
  minimumCount: number | undefined;
  maximumCount: number | undefined;
}
export interface ActionTypeSettings {
  thirdPartyConfigurationUrl?: string | undefined;
  entityUrlTemplate?: string | undefined;
  executionUrlTemplate?: string | undefined;
  revisionUrlTemplate?: string | undefined;
}
export interface ActionType {
  id: ActionTypeId | undefined;
  settings?: ActionTypeSettings | undefined;
  actionConfigurationProperties?: ActionConfigurationProperty[] | undefined;
  inputArtifactDetails: ArtifactDetails | undefined;
  outputArtifactDetails: ArtifactDetails | undefined;
}
export interface ActionTypeArtifactDetails {
  minimumCount: number | undefined;
  maximumCount: number | undefined;
}
export interface JobWorkerExecutorConfiguration {
  pollingAccounts?: string[] | undefined;
  pollingServicePrincipals?: string[] | undefined;
}
export interface LambdaExecutorConfiguration {
  lambdaFunctionArn: string | undefined;
}
export interface ExecutorConfiguration {
  lambdaExecutorConfiguration?: LambdaExecutorConfiguration | undefined;
  jobWorkerExecutorConfiguration?: JobWorkerExecutorConfiguration | undefined;
}
export declare const ExecutorType: {
  readonly JobWorker: "JobWorker";
  readonly Lambda: "Lambda";
};
export type ExecutorType = (typeof ExecutorType)[keyof typeof ExecutorType];
export interface ActionTypeExecutor {
  configuration: ExecutorConfiguration | undefined;
  type: ExecutorType | undefined;
  policyStatementsTemplate?: string | undefined;
  jobTimeout?: number | undefined;
}
export interface ActionTypeIdentifier {
  category: ActionCategory | undefined;
  owner: string | undefined;
  provider: string | undefined;
  version: string | undefined;
}
export interface ActionTypePermissions {
  allowedAccounts: string[] | undefined;
}
export interface ActionTypeProperty {
  name: string | undefined;
  optional: boolean | undefined;
  key: boolean | undefined;
  noEcho: boolean | undefined;
  queryable?: boolean | undefined;
  description?: string | undefined;
}
export interface ActionTypeUrls {
  configurationUrl?: string | undefined;
  entityUrlTemplate?: string | undefined;
  executionUrlTemplate?: string | undefined;
  revisionUrlTemplate?: string | undefined;
}
export interface ActionTypeDeclaration {
  description?: string | undefined;
  executor: ActionTypeExecutor | undefined;
  id: ActionTypeIdentifier | undefined;
  inputArtifactDetails: ActionTypeArtifactDetails | undefined;
  outputArtifactDetails: ActionTypeArtifactDetails | undefined;
  permissions?: ActionTypePermissions | undefined;
  properties?: ActionTypeProperty[] | undefined;
  urls?: ActionTypeUrls | undefined;
}
export declare class ActionTypeNotFoundException extends __BaseException {
  readonly name: "ActionTypeNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ActionTypeNotFoundException, __BaseException>
  );
}
export declare class ApprovalAlreadyCompletedException extends __BaseException {
  readonly name: "ApprovalAlreadyCompletedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ApprovalAlreadyCompletedException,
      __BaseException
    >
  );
}
export declare const ApprovalStatus: {
  readonly Approved: "Approved";
  readonly Rejected: "Rejected";
};
export type ApprovalStatus =
  (typeof ApprovalStatus)[keyof typeof ApprovalStatus];
export interface ApprovalResult {
  summary: string | undefined;
  status: ApprovalStatus | undefined;
}
export interface S3ArtifactLocation {
  bucketName: string | undefined;
  objectKey: string | undefined;
}
export declare const ArtifactLocationType: {
  readonly S3: "S3";
};
export type ArtifactLocationType =
  (typeof ArtifactLocationType)[keyof typeof ArtifactLocationType];
export interface ArtifactLocation {
  type?: ArtifactLocationType | undefined;
  s3Location?: S3ArtifactLocation | undefined;
}
export interface Artifact {
  name?: string | undefined;
  revision?: string | undefined;
  location?: ArtifactLocation | undefined;
}
export interface ArtifactRevision {
  name?: string | undefined;
  revisionId?: string | undefined;
  revisionChangeIdentifier?: string | undefined;
  revisionSummary?: string | undefined;
  created?: Date | undefined;
  revisionUrl?: string | undefined;
}
export declare const EncryptionKeyType: {
  readonly KMS: "KMS";
};
export type EncryptionKeyType =
  (typeof EncryptionKeyType)[keyof typeof EncryptionKeyType];
export interface EncryptionKey {
  id: string | undefined;
  type: EncryptionKeyType | undefined;
}
export declare const ArtifactStoreType: {
  readonly S3: "S3";
};
export type ArtifactStoreType =
  (typeof ArtifactStoreType)[keyof typeof ArtifactStoreType];
export interface ArtifactStore {
  type: ArtifactStoreType | undefined;
  location: string | undefined;
  encryptionKey?: EncryptionKey | undefined;
}
export interface AWSSessionCredentials {
  accessKeyId: string | undefined;
  secretAccessKey: string | undefined;
  sessionToken: string | undefined;
}
export declare const Result: {
  readonly FAIL: "FAIL";
  readonly RETRY: "RETRY";
  readonly ROLLBACK: "ROLLBACK";
  readonly SKIP: "SKIP";
};
export type Result = (typeof Result)[keyof typeof Result];
export declare const RuleCategory: {
  readonly Rule: "Rule";
};
export type RuleCategory = (typeof RuleCategory)[keyof typeof RuleCategory];
export declare const RuleOwner: {
  readonly AWS: "AWS";
};
export type RuleOwner = (typeof RuleOwner)[keyof typeof RuleOwner];
export interface RuleTypeId {
  category: RuleCategory | undefined;
  owner?: RuleOwner | undefined;
  provider: string | undefined;
  version?: string | undefined;
}
export interface RuleDeclaration {
  name: string | undefined;
  ruleTypeId: RuleTypeId | undefined;
  configuration?: Record<string, string> | undefined;
  commands?: string[] | undefined;
  inputArtifacts?: InputArtifact[] | undefined;
  roleArn?: string | undefined;
  region?: string | undefined;
  timeoutInMinutes?: number | undefined;
}
export interface Condition {
  result?: Result | undefined;
  rules?: RuleDeclaration[] | undefined;
}
export interface BeforeEntryConditions {
  conditions: Condition[] | undefined;
}
export declare const BlockerType: {
  readonly Schedule: "Schedule";
};
export type BlockerType = (typeof BlockerType)[keyof typeof BlockerType];
export interface BlockerDeclaration {
  name: string | undefined;
  type: BlockerType | undefined;
}
export declare class ConcurrentModificationException extends __BaseException {
  readonly name: "ConcurrentModificationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ConcurrentModificationException,
      __BaseException
    >
  );
}
export interface Tag {
  key: string | undefined;
  value: string | undefined;
}
export interface CreateCustomActionTypeInput {
  category: ActionCategory | undefined;
  provider: string | undefined;
  version: string | undefined;
  settings?: ActionTypeSettings | undefined;
  configurationProperties?: ActionConfigurationProperty[] | undefined;
  inputArtifactDetails: ArtifactDetails | undefined;
  outputArtifactDetails: ArtifactDetails | undefined;
  tags?: Tag[] | undefined;
}
export interface CreateCustomActionTypeOutput {
  actionType: ActionType | undefined;
  tags?: Tag[] | undefined;
}
export declare class InvalidTagsException extends __BaseException {
  readonly name: "InvalidTagsException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidTagsException, __BaseException>
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class TooManyTagsException extends __BaseException {
  readonly name: "TooManyTagsException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<TooManyTagsException, __BaseException>
  );
}
export declare const ExecutionMode: {
  readonly PARALLEL: "PARALLEL";
  readonly QUEUED: "QUEUED";
  readonly SUPERSEDED: "SUPERSEDED";
};
export type ExecutionMode = (typeof ExecutionMode)[keyof typeof ExecutionMode];
export declare const PipelineType: {
  readonly V1: "V1";
  readonly V2: "V2";
};
export type PipelineType = (typeof PipelineType)[keyof typeof PipelineType];
export declare const StageRetryMode: {
  readonly ALL_ACTIONS: "ALL_ACTIONS";
  readonly FAILED_ACTIONS: "FAILED_ACTIONS";
};
export type StageRetryMode =
  (typeof StageRetryMode)[keyof typeof StageRetryMode];
export interface RetryConfiguration {
  retryMode?: StageRetryMode | undefined;
}
export interface FailureConditions {
  result?: Result | undefined;
  retryConfiguration?: RetryConfiguration | undefined;
  conditions?: Condition[] | undefined;
}
export interface SuccessConditions {
  conditions: Condition[] | undefined;
}
export interface StageDeclaration {
  name: string | undefined;
  blockers?: BlockerDeclaration[] | undefined;
  actions: ActionDeclaration[] | undefined;
  onFailure?: FailureConditions | undefined;
  onSuccess?: SuccessConditions | undefined;
  beforeEntry?: BeforeEntryConditions | undefined;
}
export interface GitBranchFilterCriteria {
  includes?: string[] | undefined;
  excludes?: string[] | undefined;
}
export declare const GitPullRequestEventType: {
  readonly CLOSED: "CLOSED";
  readonly OPEN: "OPEN";
  readonly UPDATED: "UPDATED";
};
export type GitPullRequestEventType =
  (typeof GitPullRequestEventType)[keyof typeof GitPullRequestEventType];
export interface GitFilePathFilterCriteria {
  includes?: string[] | undefined;
  excludes?: string[] | undefined;
}
export interface GitPullRequestFilter {
  events?: GitPullRequestEventType[] | undefined;
  branches?: GitBranchFilterCriteria | undefined;
  filePaths?: GitFilePathFilterCriteria | undefined;
}
export interface GitTagFilterCriteria {
  includes?: string[] | undefined;
  excludes?: string[] | undefined;
}
export interface GitPushFilter {
  tags?: GitTagFilterCriteria | undefined;
  branches?: GitBranchFilterCriteria | undefined;
  filePaths?: GitFilePathFilterCriteria | undefined;
}
export interface GitConfiguration {
  sourceActionName: string | undefined;
  push?: GitPushFilter[] | undefined;
  pullRequest?: GitPullRequestFilter[] | undefined;
}
export declare const PipelineTriggerProviderType: {
  readonly CodeStarSourceConnection: "CodeStarSourceConnection";
};
export type PipelineTriggerProviderType =
  (typeof PipelineTriggerProviderType)[keyof typeof PipelineTriggerProviderType];
export interface PipelineTriggerDeclaration {
  providerType: PipelineTriggerProviderType | undefined;
  gitConfiguration: GitConfiguration | undefined;
}
export interface PipelineVariableDeclaration {
  name: string | undefined;
  defaultValue?: string | undefined;
  description?: string | undefined;
}
export interface PipelineDeclaration {
  name: string | undefined;
  roleArn: string | undefined;
  artifactStore?: ArtifactStore | undefined;
  artifactStores?: Record<string, ArtifactStore> | undefined;
  stages: StageDeclaration[] | undefined;
  version?: number | undefined;
  executionMode?: ExecutionMode | undefined;
  pipelineType?: PipelineType | undefined;
  variables?: PipelineVariableDeclaration[] | undefined;
  triggers?: PipelineTriggerDeclaration[] | undefined;
}
export interface CreatePipelineInput {
  pipeline: PipelineDeclaration | undefined;
  tags?: Tag[] | undefined;
}
export interface CreatePipelineOutput {
  pipeline?: PipelineDeclaration | undefined;
  tags?: Tag[] | undefined;
}
export declare class InvalidActionDeclarationException extends __BaseException {
  readonly name: "InvalidActionDeclarationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidActionDeclarationException,
      __BaseException
    >
  );
}
export declare class InvalidBlockerDeclarationException extends __BaseException {
  readonly name: "InvalidBlockerDeclarationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidBlockerDeclarationException,
      __BaseException
    >
  );
}
export declare class InvalidStageDeclarationException extends __BaseException {
  readonly name: "InvalidStageDeclarationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidStageDeclarationException,
      __BaseException
    >
  );
}
export declare class InvalidStructureException extends __BaseException {
  readonly name: "InvalidStructureException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidStructureException, __BaseException>
  );
}
export declare class PipelineNameInUseException extends __BaseException {
  readonly name: "PipelineNameInUseException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<PipelineNameInUseException, __BaseException>
  );
}
export interface DeleteCustomActionTypeInput {
  category: ActionCategory | undefined;
  provider: string | undefined;
  version: string | undefined;
}
export interface DeletePipelineInput {
  name: string | undefined;
}
export interface DeleteWebhookInput {
  name: string | undefined;
}
export interface DeleteWebhookOutput {}
export interface DeregisterWebhookWithThirdPartyInput {
  webhookName?: string | undefined;
}
export interface DeregisterWebhookWithThirdPartyOutput {}
export declare class WebhookNotFoundException extends __BaseException {
  readonly name: "WebhookNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<WebhookNotFoundException, __BaseException>
  );
}
export declare const StageTransitionType: {
  readonly Inbound: "Inbound";
  readonly Outbound: "Outbound";
};
export type StageTransitionType =
  (typeof StageTransitionType)[keyof typeof StageTransitionType];
export interface DisableStageTransitionInput {
  pipelineName: string | undefined;
  stageName: string | undefined;
  transitionType: StageTransitionType | undefined;
  reason: string | undefined;
}
export declare class PipelineNotFoundException extends __BaseException {
  readonly name: "PipelineNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<PipelineNotFoundException, __BaseException>
  );
}
export declare class StageNotFoundException extends __BaseException {
  readonly name: "StageNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StageNotFoundException, __BaseException>
  );
}
export interface EnableStageTransitionInput {
  pipelineName: string | undefined;
  stageName: string | undefined;
  transitionType: StageTransitionType | undefined;
}
export interface GetActionTypeInput {
  category: ActionCategory | undefined;
  owner: string | undefined;
  provider: string | undefined;
  version: string | undefined;
}
export interface GetActionTypeOutput {
  actionType?: ActionTypeDeclaration | undefined;
}
export interface GetJobDetailsInput {
  jobId: string | undefined;
}
export interface StageContext {
  name?: string | undefined;
}
export interface PipelineContext {
  pipelineName?: string | undefined;
  stage?: StageContext | undefined;
  action?: ActionContext | undefined;
  pipelineArn?: string | undefined;
  pipelineExecutionId?: string | undefined;
}
export interface JobData {
  actionTypeId?: ActionTypeId | undefined;
  actionConfiguration?: ActionConfiguration | undefined;
  pipelineContext?: PipelineContext | undefined;
  inputArtifacts?: Artifact[] | undefined;
  outputArtifacts?: Artifact[] | undefined;
  artifactCredentials?: AWSSessionCredentials | undefined;
  continuationToken?: string | undefined;
  encryptionKey?: EncryptionKey | undefined;
}
export interface JobDetails {
  id?: string | undefined;
  data?: JobData | undefined;
  accountId?: string | undefined;
}
export interface GetJobDetailsOutput {
  jobDetails?: JobDetails | undefined;
}
export interface GetPipelineInput {
  name: string | undefined;
  version?: number | undefined;
}
export interface PipelineMetadata {
  pipelineArn?: string | undefined;
  created?: Date | undefined;
  updated?: Date | undefined;
  pollingDisabledAt?: Date | undefined;
}
export interface GetPipelineOutput {
  pipeline?: PipelineDeclaration | undefined;
  metadata?: PipelineMetadata | undefined;
}
export declare class PipelineVersionNotFoundException extends __BaseException {
  readonly name: "PipelineVersionNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      PipelineVersionNotFoundException,
      __BaseException
    >
  );
}
export interface GetPipelineExecutionInput {
  pipelineName: string | undefined;
  pipelineExecutionId: string | undefined;
}
export declare const ExecutionType: {
  readonly ROLLBACK: "ROLLBACK";
  readonly STANDARD: "STANDARD";
};
export type ExecutionType = (typeof ExecutionType)[keyof typeof ExecutionType];
export interface PipelineRollbackMetadata {
  rollbackTargetPipelineExecutionId?: string | undefined;
}
export declare const PipelineExecutionStatus: {
  readonly Cancelled: "Cancelled";
  readonly Failed: "Failed";
  readonly InProgress: "InProgress";
  readonly Stopped: "Stopped";
  readonly Stopping: "Stopping";
  readonly Succeeded: "Succeeded";
  readonly Superseded: "Superseded";
};
export type PipelineExecutionStatus =
  (typeof PipelineExecutionStatus)[keyof typeof PipelineExecutionStatus];
export declare const TriggerType: {
  readonly AutomatedRollback: "AutomatedRollback";
  readonly CloudWatchEvent: "CloudWatchEvent";
  readonly CreatePipeline: "CreatePipeline";
  readonly ManualRollback: "ManualRollback";
  readonly PollForSourceChanges: "PollForSourceChanges";
  readonly PutActionRevision: "PutActionRevision";
  readonly StartPipelineExecution: "StartPipelineExecution";
  readonly Webhook: "Webhook";
  readonly WebhookV2: "WebhookV2";
};
export type TriggerType = (typeof TriggerType)[keyof typeof TriggerType];
export interface ExecutionTrigger {
  triggerType?: TriggerType | undefined;
  triggerDetail?: string | undefined;
}
export interface ResolvedPipelineVariable {
  name?: string | undefined;
  resolvedValue?: string | undefined;
}
export interface PipelineExecution {
  pipelineName?: string | undefined;
  pipelineVersion?: number | undefined;
  pipelineExecutionId?: string | undefined;
  status?: PipelineExecutionStatus | undefined;
  statusSummary?: string | undefined;
  artifactRevisions?: ArtifactRevision[] | undefined;
  variables?: ResolvedPipelineVariable[] | undefined;
  trigger?: ExecutionTrigger | undefined;
  executionMode?: ExecutionMode | undefined;
  executionType?: ExecutionType | undefined;
  rollbackMetadata?: PipelineRollbackMetadata | undefined;
}
export interface GetPipelineExecutionOutput {
  pipelineExecution?: PipelineExecution | undefined;
}
export declare class PipelineExecutionNotFoundException extends __BaseException {
  readonly name: "PipelineExecutionNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      PipelineExecutionNotFoundException,
      __BaseException
    >
  );
}
export interface GetPipelineStateInput {
  name: string | undefined;
}
export declare const ConditionExecutionStatus: {
  readonly Abandoned: "Abandoned";
  readonly Cancelled: "Cancelled";
  readonly Errored: "Errored";
  readonly Failed: "Failed";
  readonly InProgress: "InProgress";
  readonly Overridden: "Overridden";
  readonly Succeeded: "Succeeded";
};
export type ConditionExecutionStatus =
  (typeof ConditionExecutionStatus)[keyof typeof ConditionExecutionStatus];
export interface ConditionExecution {
  status?: ConditionExecutionStatus | undefined;
  summary?: string | undefined;
  lastStatusChange?: Date | undefined;
}
export interface RuleRevision {
  revisionId: string | undefined;
  revisionChangeId: string | undefined;
  created: Date | undefined;
}
export declare const RuleExecutionStatus: {
  readonly Abandoned: "Abandoned";
  readonly Failed: "Failed";
  readonly InProgress: "InProgress";
  readonly Succeeded: "Succeeded";
};
export type RuleExecutionStatus =
  (typeof RuleExecutionStatus)[keyof typeof RuleExecutionStatus];
export interface RuleExecution {
  ruleExecutionId?: string | undefined;
  status?: RuleExecutionStatus | undefined;
  summary?: string | undefined;
  lastStatusChange?: Date | undefined;
  token?: string | undefined;
  lastUpdatedBy?: string | undefined;
  externalExecutionId?: string | undefined;
  externalExecutionUrl?: string | undefined;
  errorDetails?: ErrorDetails | undefined;
}
export interface RuleState {
  ruleName?: string | undefined;
  currentRevision?: RuleRevision | undefined;
  latestExecution?: RuleExecution | undefined;
  entityUrl?: string | undefined;
  revisionUrl?: string | undefined;
}
export interface ConditionState {
  latestExecution?: ConditionExecution | undefined;
  ruleStates?: RuleState[] | undefined;
}
export interface StageConditionsExecution {
  status?: ConditionExecutionStatus | undefined;
  summary?: string | undefined;
}
export interface StageConditionState {
  latestExecution?: StageConditionsExecution | undefined;
  conditionStates?: ConditionState[] | undefined;
}
export declare const StageExecutionStatus: {
  readonly Cancelled: "Cancelled";
  readonly Failed: "Failed";
  readonly InProgress: "InProgress";
  readonly Skipped: "Skipped";
  readonly Stopped: "Stopped";
  readonly Stopping: "Stopping";
  readonly Succeeded: "Succeeded";
};
export type StageExecutionStatus =
  (typeof StageExecutionStatus)[keyof typeof StageExecutionStatus];
export interface StageExecution {
  pipelineExecutionId: string | undefined;
  status: StageExecutionStatus | undefined;
  type?: ExecutionType | undefined;
}
export interface TransitionState {
  enabled?: boolean | undefined;
  lastChangedBy?: string | undefined;
  lastChangedAt?: Date | undefined;
  disabledReason?: string | undefined;
}
export declare const RetryTrigger: {
  readonly AutomatedStageRetry: "AutomatedStageRetry";
  readonly ManualStageRetry: "ManualStageRetry";
};
export type RetryTrigger = (typeof RetryTrigger)[keyof typeof RetryTrigger];
export interface RetryStageMetadata {
  autoStageRetryAttempt?: number | undefined;
  manualStageRetryAttempt?: number | undefined;
  latestRetryTrigger?: RetryTrigger | undefined;
}
export interface StageState {
  stageName?: string | undefined;
  inboundExecution?: StageExecution | undefined;
  inboundExecutions?: StageExecution[] | undefined;
  inboundTransitionState?: TransitionState | undefined;
  actionStates?: ActionState[] | undefined;
  latestExecution?: StageExecution | undefined;
  beforeEntryConditionState?: StageConditionState | undefined;
  onSuccessConditionState?: StageConditionState | undefined;
  onFailureConditionState?: StageConditionState | undefined;
  retryStageMetadata?: RetryStageMetadata | undefined;
}
export interface GetPipelineStateOutput {
  pipelineName?: string | undefined;
  pipelineVersion?: number | undefined;
  stageStates?: StageState[] | undefined;
  created?: Date | undefined;
  updated?: Date | undefined;
}
export interface GetThirdPartyJobDetailsInput {
  jobId: string | undefined;
  clientToken: string | undefined;
}
export interface ThirdPartyJobData {
  actionTypeId?: ActionTypeId | undefined;
  actionConfiguration?: ActionConfiguration | undefined;
  pipelineContext?: PipelineContext | undefined;
  inputArtifacts?: Artifact[] | undefined;
  outputArtifacts?: Artifact[] | undefined;
  artifactCredentials?: AWSSessionCredentials | undefined;
  continuationToken?: string | undefined;
  encryptionKey?: EncryptionKey | undefined;
}
export interface ThirdPartyJobDetails {
  id?: string | undefined;
  data?: ThirdPartyJobData | undefined;
  nonce?: string | undefined;
}
export interface GetThirdPartyJobDetailsOutput {
  jobDetails?: ThirdPartyJobDetails | undefined;
}
export declare class InvalidJobException extends __BaseException {
  readonly name: "InvalidJobException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidJobException, __BaseException>
  );
}
export declare class InvalidNextTokenException extends __BaseException {
  readonly name: "InvalidNextTokenException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidNextTokenException, __BaseException>
  );
}
export interface ListActionExecutionsInput {
  pipelineName: string | undefined;
  filter?: ActionExecutionFilter | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface ListActionExecutionsOutput {
  actionExecutionDetails?: ActionExecutionDetail[] | undefined;
  nextToken?: string | undefined;
}
export interface ListActionTypesInput {
  actionOwnerFilter?: ActionOwner | undefined;
  nextToken?: string | undefined;
  regionFilter?: string | undefined;
}
export interface ListActionTypesOutput {
  actionTypes: ActionType[] | undefined;
  nextToken?: string | undefined;
}
export interface SucceededInStageFilter {
  stageName?: string | undefined;
}
export interface PipelineExecutionFilter {
  succeededInStage?: SucceededInStageFilter | undefined;
}
export interface ListPipelineExecutionsInput {
  pipelineName: string | undefined;
  maxResults?: number | undefined;
  filter?: PipelineExecutionFilter | undefined;
  nextToken?: string | undefined;
}
export interface SourceRevision {
  actionName: string | undefined;
  revisionId?: string | undefined;
  revisionSummary?: string | undefined;
  revisionUrl?: string | undefined;
}
export interface StopExecutionTrigger {
  reason?: string | undefined;
}
export interface PipelineExecutionSummary {
  pipelineExecutionId?: string | undefined;
  status?: PipelineExecutionStatus | undefined;
  statusSummary?: string | undefined;
  startTime?: Date | undefined;
  lastUpdateTime?: Date | undefined;
  sourceRevisions?: SourceRevision[] | undefined;
  trigger?: ExecutionTrigger | undefined;
  stopTrigger?: StopExecutionTrigger | undefined;
  executionMode?: ExecutionMode | undefined;
  executionType?: ExecutionType | undefined;
  rollbackMetadata?: PipelineRollbackMetadata | undefined;
}
export interface ListPipelineExecutionsOutput {
  pipelineExecutionSummaries?: PipelineExecutionSummary[] | undefined;
  nextToken?: string | undefined;
}
export interface ListPipelinesInput {
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface PipelineSummary {
  name?: string | undefined;
  version?: number | undefined;
  pipelineType?: PipelineType | undefined;
  executionMode?: ExecutionMode | undefined;
  created?: Date | undefined;
  updated?: Date | undefined;
}
export interface ListPipelinesOutput {
  pipelines?: PipelineSummary[] | undefined;
  nextToken?: string | undefined;
}
export interface RuleExecutionFilter {
  pipelineExecutionId?: string | undefined;
  latestInPipelineExecution?: LatestInPipelineExecutionFilter | undefined;
}
export interface ListRuleExecutionsInput {
  pipelineName: string | undefined;
  filter?: RuleExecutionFilter | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface RuleExecutionInput {
  ruleTypeId?: RuleTypeId | undefined;
  configuration?: Record<string, string> | undefined;
  resolvedConfiguration?: Record<string, string> | undefined;
  roleArn?: string | undefined;
  region?: string | undefined;
  inputArtifacts?: ArtifactDetail[] | undefined;
}
export interface RuleExecutionResult {
  externalExecutionId?: string | undefined;
  externalExecutionSummary?: string | undefined;
  externalExecutionUrl?: string | undefined;
  errorDetails?: ErrorDetails | undefined;
}
export interface RuleExecutionOutput {
  executionResult?: RuleExecutionResult | undefined;
}
export interface RuleExecutionDetail {
  pipelineExecutionId?: string | undefined;
  ruleExecutionId?: string | undefined;
  pipelineVersion?: number | undefined;
  stageName?: string | undefined;
  ruleName?: string | undefined;
  startTime?: Date | undefined;
  lastUpdateTime?: Date | undefined;
  updatedBy?: string | undefined;
  status?: RuleExecutionStatus | undefined;
  input?: RuleExecutionInput | undefined;
  output?: RuleExecutionOutput | undefined;
}
export interface ListRuleExecutionsOutput {
  ruleExecutionDetails?: RuleExecutionDetail[] | undefined;
  nextToken?: string | undefined;
}
export interface ListRuleTypesInput {
  ruleOwnerFilter?: RuleOwner | undefined;
  regionFilter?: string | undefined;
}
export declare const RuleConfigurationPropertyType: {
  readonly Boolean: "Boolean";
  readonly Number: "Number";
  readonly String: "String";
};
export type RuleConfigurationPropertyType =
  (typeof RuleConfigurationPropertyType)[keyof typeof RuleConfigurationPropertyType];
export interface RuleConfigurationProperty {
  name: string | undefined;
  required: boolean | undefined;
  key: boolean | undefined;
  secret: boolean | undefined;
  queryable?: boolean | undefined;
  description?: string | undefined;
  type?: RuleConfigurationPropertyType | undefined;
}
export interface RuleTypeSettings {
  thirdPartyConfigurationUrl?: string | undefined;
  entityUrlTemplate?: string | undefined;
  executionUrlTemplate?: string | undefined;
  revisionUrlTemplate?: string | undefined;
}
export interface RuleType {
  id: RuleTypeId | undefined;
  settings?: RuleTypeSettings | undefined;
  ruleConfigurationProperties?: RuleConfigurationProperty[] | undefined;
  inputArtifactDetails: ArtifactDetails | undefined;
}
export interface ListRuleTypesOutput {
  ruleTypes: RuleType[] | undefined;
}
export declare class InvalidArnException extends __BaseException {
  readonly name: "InvalidArnException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidArnException, __BaseException>
  );
}
export interface ListTagsForResourceInput {
  resourceArn: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListTagsForResourceOutput {
  tags?: Tag[] | undefined;
  nextToken?: string | undefined;
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export interface ListWebhooksInput {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export declare const WebhookAuthenticationType: {
  readonly GITHUB_HMAC: "GITHUB_HMAC";
  readonly IP: "IP";
  readonly UNAUTHENTICATED: "UNAUTHENTICATED";
};
export type WebhookAuthenticationType =
  (typeof WebhookAuthenticationType)[keyof typeof WebhookAuthenticationType];
export interface WebhookAuthConfiguration {
  AllowedIPRange?: string | undefined;
  SecretToken?: string | undefined;
}
export interface WebhookFilterRule {
  jsonPath: string | undefined;
  matchEquals?: string | undefined;
}
export interface WebhookDefinition {
  name: string | undefined;
  targetPipeline: string | undefined;
  targetAction: string | undefined;
  filters: WebhookFilterRule[] | undefined;
  authentication: WebhookAuthenticationType | undefined;
  authenticationConfiguration: WebhookAuthConfiguration | undefined;
}
export interface ListWebhookItem {
  definition: WebhookDefinition | undefined;
  url: string | undefined;
  errorMessage?: string | undefined;
  errorCode?: string | undefined;
  lastTriggered?: Date | undefined;
  arn?: string | undefined;
  tags?: Tag[] | undefined;
}
export interface ListWebhooksOutput {
  webhooks?: ListWebhookItem[] | undefined;
  NextToken?: string | undefined;
}
export declare class ConcurrentPipelineExecutionsLimitExceededException extends __BaseException {
  readonly name: "ConcurrentPipelineExecutionsLimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ConcurrentPipelineExecutionsLimitExceededException,
      __BaseException
    >
  );
}
export declare class ConditionNotOverridableException extends __BaseException {
  readonly name: "ConditionNotOverridableException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ConditionNotOverridableException,
      __BaseException
    >
  );
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare class NotLatestPipelineExecutionException extends __BaseException {
  readonly name: "NotLatestPipelineExecutionException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      NotLatestPipelineExecutionException,
      __BaseException
    >
  );
}
export declare const ConditionType: {
  readonly BEFORE_ENTRY: "BEFORE_ENTRY";
  readonly ON_SUCCESS: "ON_SUCCESS";
};
export type ConditionType = (typeof ConditionType)[keyof typeof ConditionType];
export interface OverrideStageConditionInput {
  pipelineName: string | undefined;
  stageName: string | undefined;
  pipelineExecutionId: string | undefined;
  conditionType: ConditionType | undefined;
}
export interface PollForJobsInput {
  actionTypeId: ActionTypeId | undefined;
  maxBatchSize?: number | undefined;
  queryParam?: Record<string, string> | undefined;
}
export interface Job {
  id?: string | undefined;
  data?: JobData | undefined;
  nonce?: string | undefined;
  accountId?: string | undefined;
}
export interface PollForJobsOutput {
  jobs?: Job[] | undefined;
}
export interface PollForThirdPartyJobsInput {
  actionTypeId: ActionTypeId | undefined;
  maxBatchSize?: number | undefined;
}
export interface ThirdPartyJob {
  clientId?: string | undefined;
  jobId?: string | undefined;
}
export interface PollForThirdPartyJobsOutput {
  jobs?: ThirdPartyJob[] | undefined;
}
export interface PutActionRevisionInput {
  pipelineName: string | undefined;
  stageName: string | undefined;
  actionName: string | undefined;
  actionRevision: ActionRevision | undefined;
}
export interface PutActionRevisionOutput {
  newRevision?: boolean | undefined;
  pipelineExecutionId?: string | undefined;
}
export declare class InvalidApprovalTokenException extends __BaseException {
  readonly name: "InvalidApprovalTokenException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidApprovalTokenException, __BaseException>
  );
}
export interface PutApprovalResultInput {
  pipelineName: string | undefined;
  stageName: string | undefined;
  actionName: string | undefined;
  result: ApprovalResult | undefined;
  token: string | undefined;
}
export interface PutApprovalResultOutput {
  approvedAt?: Date | undefined;
}
export declare class InvalidJobStateException extends __BaseException {
  readonly name: "InvalidJobStateException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidJobStateException, __BaseException>
  );
}
export declare const FailureType: {
  readonly ConfigurationError: "ConfigurationError";
  readonly JobFailed: "JobFailed";
  readonly PermissionError: "PermissionError";
  readonly RevisionOutOfSync: "RevisionOutOfSync";
  readonly RevisionUnavailable: "RevisionUnavailable";
  readonly SystemUnavailable: "SystemUnavailable";
};
export type FailureType = (typeof FailureType)[keyof typeof FailureType];
export interface FailureDetails {
  type: FailureType | undefined;
  message: string | undefined;
  externalExecutionId?: string | undefined;
}
export interface PutJobFailureResultInput {
  jobId: string | undefined;
  failureDetails: FailureDetails | undefined;
}
export declare class OutputVariablesSizeExceededException extends __BaseException {
  readonly name: "OutputVariablesSizeExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      OutputVariablesSizeExceededException,
      __BaseException
    >
  );
}
export interface CurrentRevision {
  revision: string | undefined;
  changeIdentifier: string | undefined;
  created?: Date | undefined;
  revisionSummary?: string | undefined;
}
export interface ExecutionDetails {
  summary?: string | undefined;
  externalExecutionId?: string | undefined;
  percentComplete?: number | undefined;
}
export interface PutJobSuccessResultInput {
  jobId: string | undefined;
  currentRevision?: CurrentRevision | undefined;
  continuationToken?: string | undefined;
  executionDetails?: ExecutionDetails | undefined;
  outputVariables?: Record<string, string> | undefined;
}
export interface PutThirdPartyJobFailureResultInput {
  jobId: string | undefined;
  clientToken: string | undefined;
  failureDetails: FailureDetails | undefined;
}
export interface PutThirdPartyJobSuccessResultInput {
  jobId: string | undefined;
  clientToken: string | undefined;
  currentRevision?: CurrentRevision | undefined;
  continuationToken?: string | undefined;
  executionDetails?: ExecutionDetails | undefined;
}
export declare class InvalidWebhookAuthenticationParametersException extends __BaseException {
  readonly name: "InvalidWebhookAuthenticationParametersException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidWebhookAuthenticationParametersException,
      __BaseException
    >
  );
}
export declare class InvalidWebhookFilterPatternException extends __BaseException {
  readonly name: "InvalidWebhookFilterPatternException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidWebhookFilterPatternException,
      __BaseException
    >
  );
}
export interface PutWebhookInput {
  webhook: WebhookDefinition | undefined;
  tags?: Tag[] | undefined;
}
export interface PutWebhookOutput {
  webhook?: ListWebhookItem | undefined;
}
export interface RegisterWebhookWithThirdPartyInput {
  webhookName?: string | undefined;
}
export interface RegisterWebhookWithThirdPartyOutput {}
export interface RetryStageExecutionInput {
  pipelineName: string | undefined;
  stageName: string | undefined;
  pipelineExecutionId: string | undefined;
  retryMode: StageRetryMode | undefined;
}
export interface RetryStageExecutionOutput {
  pipelineExecutionId?: string | undefined;
}
export declare class StageNotRetryableException extends __BaseException {
  readonly name: "StageNotRetryableException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<StageNotRetryableException, __BaseException>
  );
}
export declare class PipelineExecutionOutdatedException extends __BaseException {
  readonly name: "PipelineExecutionOutdatedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      PipelineExecutionOutdatedException,
      __BaseException
    >
  );
}
export interface RollbackStageInput {
  pipelineName: string | undefined;
  stageName: string | undefined;
  targetPipelineExecutionId: string | undefined;
}
export interface RollbackStageOutput {
  pipelineExecutionId: string | undefined;
}
export declare class UnableToRollbackStageException extends __BaseException {
  readonly name: "UnableToRollbackStageException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<UnableToRollbackStageException, __BaseException>
  );
}
export declare const SourceRevisionType: {
  readonly COMMIT_ID: "COMMIT_ID";
  readonly IMAGE_DIGEST: "IMAGE_DIGEST";
  readonly S3_OBJECT_KEY: "S3_OBJECT_KEY";
  readonly S3_OBJECT_VERSION_ID: "S3_OBJECT_VERSION_ID";
};
export type SourceRevisionType =
  (typeof SourceRevisionType)[keyof typeof SourceRevisionType];
export interface SourceRevisionOverride {
  actionName: string | undefined;
  revisionType: SourceRevisionType | undefined;
  revisionValue: string | undefined;
}
export interface PipelineVariable {
  name: string | undefined;
  value: string | undefined;
}
export interface StartPipelineExecutionInput {
  name: string | undefined;
  variables?: PipelineVariable[] | undefined;
  clientRequestToken?: string | undefined;
  sourceRevisions?: SourceRevisionOverride[] | undefined;
}
export interface StartPipelineExecutionOutput {
  pipelineExecutionId?: string | undefined;
}
export declare class DuplicatedStopRequestException extends __BaseException {
  readonly name: "DuplicatedStopRequestException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<DuplicatedStopRequestException, __BaseException>
  );
}
export declare class PipelineExecutionNotStoppableException extends __BaseException {
  readonly name: "PipelineExecutionNotStoppableException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      PipelineExecutionNotStoppableException,
      __BaseException
    >
  );
}
export interface StopPipelineExecutionInput {
  pipelineName: string | undefined;
  pipelineExecutionId: string | undefined;
  abandon?: boolean | undefined;
  reason?: string | undefined;
}
export interface StopPipelineExecutionOutput {
  pipelineExecutionId?: string | undefined;
}
export interface TagResourceInput {
  resourceArn: string | undefined;
  tags: Tag[] | undefined;
}
export interface TagResourceOutput {}
export interface UntagResourceInput {
  resourceArn: string | undefined;
  tagKeys: string[] | undefined;
}
export interface UntagResourceOutput {}
export declare class RequestFailedException extends __BaseException {
  readonly name: "RequestFailedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<RequestFailedException, __BaseException>
  );
}
export interface UpdateActionTypeInput {
  actionType: ActionTypeDeclaration | undefined;
}
export interface UpdatePipelineInput {
  pipeline: PipelineDeclaration | undefined;
}
export interface UpdatePipelineOutput {
  pipeline?: PipelineDeclaration | undefined;
}
export declare const AWSSessionCredentialsFilterSensitiveLog: (
  obj: AWSSessionCredentials
) => any;
export declare const JobDataFilterSensitiveLog: (obj: JobData) => any;
export declare const JobDetailsFilterSensitiveLog: (obj: JobDetails) => any;
export declare const GetJobDetailsOutputFilterSensitiveLog: (
  obj: GetJobDetailsOutput
) => any;
export declare const ThirdPartyJobDataFilterSensitiveLog: (
  obj: ThirdPartyJobData
) => any;
export declare const ThirdPartyJobDetailsFilterSensitiveLog: (
  obj: ThirdPartyJobDetails
) => any;
export declare const GetThirdPartyJobDetailsOutputFilterSensitiveLog: (
  obj: GetThirdPartyJobDetailsOutput
) => any;
export declare const JobFilterSensitiveLog: (obj: Job) => any;
export declare const PollForJobsOutputFilterSensitiveLog: (
  obj: PollForJobsOutput
) => any;
